/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
 * Description:激光点云, 视频图像以及Tf数据读取类
 * Create: 2021-06-03
 */

#ifndef DATA_READER_H
#define DATA_READER_H

#include <vector>
#include <display_types/viz_tf.h>
#include <display_types/viz_image.h>
#include <display_types/viz_point_cloud2.h>
#include <linear_math/lm_quaternion.h>
#include <linear_math/lm_transform.h>
//#include <sensor_msgs/CameraInfo.h>

#include <yaml-cpp/yaml.h>
#include <publisher.h>

class YamlParser {
public:
    YamlParser() = default;
    ~YamlParser() = default;

    enum Sensor {
        CAMERA,
        LIDAR
    };

public:
    const mdc::visual::Vector3 ParseTrans(Sensor sensor, const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &translationNode, const std::string &dataNode) const;
    const mdc::visual::Vector3 ParseTransCam(const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &translationNode) const;
    const mdc::visual::lm::LmMatrix3x3 ParseRotat(const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &rotationNode, const std::string &dataNode) const;
    std::vector<double> ParseCamParam(const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &secondNode, const std::string &dataNode) const;
    const uint32_t ParseResolution(const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &secondNode, const std::string &dataNode) const;
    const std::string ParseDistortionModel(const YAML::Node &fileNode, const std::string &rootNode,
        const std::string &secondNode) const;
};

#endif
